﻿-- print("Modules/Initialise.lua start")
-- *********************************
-- * Variable/Constant Declaration *
-- *********************************

LFMonitor.settingsVersion = "50200" -- used for forcing old settings to reset

LFMonitorCache = {count=0, max = 2048}
LFMonitorWordCache = {count=0, max = 2048}
-- reduce max if memory usage too high; increase if running too slowly
LFMonitor.LFM_Update_Int = 20.0
LFMonitor.CL_Update_Int = 0.5
LFMonitor.testmode = false
LFMonitor.history = {}
LFMonitor.hindex = 1
LFMonitor.TFW_PATTERN = "^_$(%d+)(.+)_$(.+)_$(.+)%$$"

-- function to deepcopy a table, from http://lua-users.org/wiki/CopyTable
function LFMonitor:deepcopy(object)

    local lookup_table = {}
    local function _copy(object)

        if type(object) ~= "table" then

            return object

        elseif lookup_table[object] then

            return lookup_table[object]

        end

        local new_table = {}
        lookup_table[object] = new_table

        for index, value in pairs(object) do

            new_table[_copy(index)] = _copy(value)

        end

        return setmetatable(new_table, getmetatable(object))

    end

    return _copy(object)

end

--concatenate two tables to produce one table
local function concatenate(t1, t2)

	local ctable = LFMonitor:deepcopy(t1)

	for _, txt in ipairs(t2) do

		table.insert(ctable, txt)

	end

	return ctable

end

--merge two or more dictionaries to produce one dictionary
local function dic_concat(...)
	local out = {}
	local i, table
	local n=select('#',...)
	for i=1,n do
		table = select(i,...)
		for key, value in pairs(table) do
			if out[key] then
				out[key] = math.max(out[key], value)
			else
				out[key] = value
			end
		end
	end
	return out
end

--build search tables
function LFMonitor:BuildTables()
	-- this function doesn't do anything anymore
end

LFMonitor.sounds = {
	[1] = {
		file = "LOOTWINDOWCOINSOUND",
		name = LFMonitor.COINS,
		type = "game"
	},
	[2] = {
		file = "INTERFACESOUND_CHARWINDOWTAB",
		name = LFMonitor.WINDOW_TAB,
		type = "game"
	},
	[3] = {
		file = "INTERFACESOUND_GAMEMENUOPEN",
		name = LFMonitor.MENU_OPENING,
		type = "game"
	},
	[4] = {
		file = "igMiniMapOpen",
		name = LFMonitor.MINIMAP_OPENING,
		type = "game"
	},
	[5] = {
		file = "igSpellBookOpen",
		name = LFMonitor.SPELLBOOK_OPENING,
		type = "game"
	},
	[6] = {
		file = "igSpellBookClose",
		name = LFMonitor.SPELLBOOK_CLOSING,
		type = "game"
	},
	[7] = {
		file = "TalentScreenOpen",
		name = LFMonitor.TALENTS_OPENING,
		type = "game"
	},
	[8] = {
		file = "igQuestLogOpen",
		name = LFMonitor.QUEST_LOG_OPENING,
		type = "game"
	},
	[9] = {
		file = "Fishing Reel in",
		name = LFMonitor.FISHING,
		type = "game"
	},
	[10]= {
		file = "HumanExploration",
		name = LFMonitor.DISCOVERY,
		type = "game"
	},
	[11]= {
		file = "applause.ogg",
		name = LFMonitor.APPLAUSE,
		type = "addon"
	},
	[12]= {
		file = "BEEPMULT.ogg",
		name = LFMonitor.BEEP,
		type = "addon"
	},
	[13]= {
		file = "CLICK10B.ogg",
		name = LFMonitor.CLICK,
		type = "addon"
	},
	[14]= {
		file = "dogbrk.ogg",
		name = LFMonitor.DOG_BARKING,
		type = "addon"
	},
	[15]= {
		file = "pcmouseclick1.ogg",
		name = LFMonitor.MOUSE_CLICK,
		type = "addon"
	},
	[16]= {
		file = "stapler2.ogg",
		name = LFMonitor.STAPLER,
		type = "addon"
	}
}

LFMonitor.fonts = {
	[1] = {
		file = "Fonts\\FRIZQT__.TTF",
		name = LFMonitor.FONT_FRIZ
	},
	[2] = {
		file = "Fonts\\ARIALN.TTF",
		name = LFMonitor.FONT_ARIALN
	},
	[3] = {
		file = "Fonts\\skurri.ttf",
		name = LFMonitor.FONT_SKURRI
	},
	[4] = {
		file = "Fonts\\MORPHEUS.ttf",
		name = LFMonitor.FONT_MORPHEUS
	}
}

LFMonitor.timestamps = {
	[1] = {
		name = _G.TIMESTAMP_FORMAT_HHMM,
		format = _G.TIMESTAMP_FORMAT_HHMM.." "
	},
	[2] = {
		name = _G.TIMESTAMP_FORMAT_HHMMSS,
		format = _G.TIMESTAMP_FORMAT_HHMMSS.." "
	},
	[3] = {
		name = _G.TIMESTAMP_FORMAT_HHMM_AMPM,
		format = _G.TIMESTAMP_FORMAT_HHMM_AMPM.." "
	},
	[4] = {
		name = _G.TIMESTAMP_FORMAT_HHMMSS_AMPM,
		format = _G.TIMESTAMP_FORMAT_HHMMSS_AMPM.." "
	},
	[5] = {
		name = _G.TIMESTAMP_FORMAT_HHMM_24HR,
		format = _G.TIMESTAMP_FORMAT_HHMM_24HR.." ",
	},
	[6] = {
		name = _G.TIMESTAMP_FORMAT_HHMMSS_24HR,
		format = _G.TIMESTAMP_FORMAT_HHMMSS_24HR.." ",
	},
	[7] = {
		name = _G.TIMESTAMP_FORMAT_NONE,
		format = "",
	}
}

LFMonitor.defaults = {
	settingsVersion = LFMonitor.settingsVersion,
	lfprof = {
		professions = {},
	},
	lfw = {
		professions = {},
	},
	lfg = {
		classes = {},
		roles = {},
		raids = {},
		overrideraid = false,
	},
	lfm = {
		classes = {},
		roles = {},
		raids = {},
		overrideraid = false,
	},
	lfguild = {
		classes = {},
		roles = {},
	},
	guildlfm = {
		classes = {},
		roles = {},
	},
	monitoring = {},
	responses = {
		jc = LFMonitor.WHISPER_ME,
		enc = LFMonitor.WHISPER_ME,
		lw = LFMonitor.WHISPER_ME,
		ins = LFMonitor.WHISPER_ME,
		tlr = LFMonitor.WHISPER_ME,
		bs = LFMonitor.WHISPER_ME,
		alc = LFMonitor.WHISPER_ME,
		eng = LFMonitor.WHISPER_ME,
		lfg = LFMonitor.LFG_RESPONSE
	},
	options = {
		scl = 1,
		hinst = 1,
		rested = false,
		combat = false,
		soundon = 1,
		sound = 15,
		locked = false,
		disabled = false,
		trade = 1,
		timestamp = 5,
		basic = "",
		adv = "",
		basicesc = "",
		useclasscolours = false,
		sensitivity = 0.5
	},
	channels = {
		general = 1,
		trade = 1,
		guild = 0
	},
	alert = {
		font = {
			index = 1,
			height = 14,
			timestamp = "ffffd200",
			player = "ff22ee55",
			text = "ffffffff"
		},
		backdrop = {
			background = "80000000",
			border = "ff87bdff"
		},
		position = {
			x = -1,
			y = -1,
			width = 575,
			height = 100
		}
	},
}

LFMonitorDB = LFMonitor:deepcopy(LFMonitor.defaults)



-- Popup dialogues
StaticPopupDialogs["LFMONITOR_NOAUTOREPLY"] = {
	text = LFMonitor.CANNOT_SEND,
	button1 = _G.OKAY,
	timeout = 0,
	whileDead = 1,
	hideOnEscape = 1
}

StaticPopupDialogs["LFMONITOR_DEFAULTS"] = {
	text = LFMonitor.RESET_CONFIRM,
	button1 = _G.YES,
	button2 = _G.NO,
	OnAccept = function() LFMonitor:ResponseOptionsDefault() end,
	timeout = 0,
	whileDead = 1,
	hideOnEscape = 1
}

--no operation used for certain request types
LFMonitor.nop = {""}
-- print("Modules/Initialise.lua end")
